@@ -1,6 +1,6 @@
 package PAUSE::Packages::ReleaseIterator;
 {
-  $PAUSE::Packages::ReleaseIterator::VERSION = '0.06';
+  $PAUSE::Packages::ReleaseIterator::VERSION = '0.07';
 }
 
 use 5.10.0;
@@ -18,7 +18,7 @@ has 'packages' =>
         default => sub { return PAUSE::Packages->new(); },
     );
 
-sub next
+sub next_release
 {
     my $self = shift;
     my @modules;
@@ -57,4 +57,7 @@ sub next
     return undef;
 }
 
+# method alias for backwards compatibility
+*next = \&next_release;
+
 1;
